org.pilosus.kairos

Crontab format parsing

Format follows that of the Vixie cron: https://man7.org/linux/man-pages/man5/crontab.5.html

┌────────────── minute (0-59) │ ┌──────────── hour (0-23) │ │ ┌────────── day of month (1-31) │ │ │ ┌──────── month (1-12 or Jan-Dec) │ │ │ │ ┌────── day of week (0-7 or Mon-Sun, 0 and 7 are Sunday) │ │ │ │ │


including support for the following Date-Time matching: (month AND hour AND minute AND (day-of-month OR day-of-week))

Short 3-letter names for months and week days are supported, e.g. Jan, Wed.

Sunday's day of week number can be either 0 or 7.

Date-Time entities are java.time.ZonedDateTime objects in given timezone or UTC by default.

Definitions:

cron entry, cron expression, or cron - a string with a schedule expression that contains fields or a nickname value. NB! In the context of kairos a cron entry does not contain a command (like original crontab file's lines do), but only a schedule expression.

field - time and date fragments of the cron entry.

values - each field contains allowed values in the form of single number or a name, their ranges, ranges with step values, lists, or an asterisk.

named value - a 3-letter name for a month or a day of week.

nickname value - one of predefined aliases for useful cron entries.

range - two numbers or named values separated by a hyphen.

step value - range of values with a given step.

list of values - values separated by comma.

Crontab format parsing

Format follows that of the Vixie cron:
https://man7.org/linux/man-pages/man5/crontab.5.html

 ┌────────────── minute (0-59)
 │ ┌──────────── hour (0-23)
 │ │ ┌────────── day of month (1-31)
 │ │ │ ┌──────── month (1-12 or Jan-Dec)
 │ │ │ │ ┌────── day of week (0-7 or Mon-Sun, 0 and 7 are Sunday)
 │ │ │ │ │
 * * * * *

including support for the following Date-Time matching:
(month AND hour AND minute AND (day-of-month OR day-of-week))

Short 3-letter names for months and week days are supported,
e.g. Jan, Wed.

Sunday's day of week number can be either 0 or 7.

Date-Time entities are java.time.ZonedDateTime objects in given
timezone or UTC by default.


Definitions:

cron entry, cron expression, or cron - a string with a schedule
expression that contains fields or a nickname value. NB! In the
context of `kairos` a cron entry does not contain a command (like
original crontab file's lines do), but only a schedule expression.

field - time and date fragments of the cron entry.

values - each field contains allowed values in the form of single
number or a name, their ranges, ranges with step values, lists, or
an asterisk.

named value - a 3-letter name for a month or a day of week.

nickname value - one of predefined aliases for useful cron entries.

range - two numbers or named values separated by a hyphen.

step value - range of values with a given step.

list of values - values separated by comma.
raw docstring

org.pilosus.kairos.locale

Predefined locale maps for cron->text localization. See org.pilosus.kairos/locale-en for the full schema.

Predefined locale maps for cron->text localization.
See org.pilosus.kairos/locale-en for the full schema.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries