Crontab format parsing
Format follows that of the Vixie cron: https://man7.org/linux/man-pages/man5/crontab.5.html
including support for the following Date-Time matching: (month AND hour AND minute AND (day-of-month OR day-of-week))
Short 3-letter names for months and week days are supported, e.g. Jan, Wed.
Sunday's day of week number can be either 0 or 7.
Date-Time entities are java.time.ZonedDateTime objects in given timezone or UTC by default.
Definitions:
field - time and date fragments of the cron entry.
values - each field contains allowed values in the form of single number or a name, their ranges, ranges with step values, lists, or an asterisk.
named value - a 3-letter name for a month or a day of week.
nickname value - one of predefined aliases for useful cron entries.
range - two numbers or named values separated by a hyphen.
step value - range of values with a given step.
list of values - values separated by comma.
Crontab format parsing Format follows that of the Vixie cron: https://man7.org/linux/man-pages/man5/crontab.5.html including support for the following Date-Time matching: (month AND hour AND minute AND (day-of-month OR day-of-week)) Short 3-letter names for months and week days are supported, e.g. Jan, Wed. Sunday's day of week number can be either 0 or 7. Date-Time entities are java.time.ZonedDateTime objects in given timezone or UTC by default. Definitions: field - time and date fragments of the cron entry. values - each field contains allowed values in the form of single number or a name, their ranges, ranges with step values, lists, or an asterisk. named value - a 3-letter name for a month or a day of week. nickname value - one of predefined aliases for useful cron entries. range - two numbers or named values separated by a hyphen. step value - range of values with a given step. list of values - values separated by comma.
(cron->dt s)(cron->dt s {:keys [start tz]})Parse crontab string into a lazy seq of ZonedDateTime objects opts: :start - ZonedDateTime after which to generate times (default: now). Only the instant matters, not its timezone - results after this point in time are included regardless of zone. :tz - ZoneId for generated datetimes (default: UTC)
Parse crontab string into a lazy seq of ZonedDateTime objects
opts:
:start - ZonedDateTime after which to generate times (default: now).
Only the instant matters, not its timezone - results after
this point in time are included regardless of zone.
:tz - ZoneId for generated datetimes (default: UTC)
(cron->map s)Parse a crontab string into a map of ranges
Parse a crontab string into a map of ranges
(cron->text s)(cron->text s {:keys [locale]})Parse crontab string into a human-readable text. opts: :locale - a locale map for translations (default: English). Partial maps are merged with the English defaults. See locale-en for the full schema.
Parse crontab string into a human-readable text.
opts:
:locale - a locale map for translations (default: English).
Partial maps are merged with the English defaults.
See locale-en for the full schema.(cron-valid? s)Return true if a crontab entry is valid
Return true if a crontab entry is valid
(cron-validate s)Return validation status and error message for a given crontab entry
Return validation status and error message for a given crontab entry
(dt-future? current-dt another-dt)Return true if provided ZonedDateTime is in the future
Return true if provided ZonedDateTime is in the future
(dt-valid? dt days-of-month days-of-week)Return true if a given ZonedDateTime satisfies day-of-month OR day-of-week constrains
Return true if a given ZonedDateTime satisfies day-of-month OR day-of-week constrains
(field->text s field)Parse field values into a human readable text
Parse field values into a human readable text
(field->values s field)Parse a string into a sequence of numbers that represent a given Date-Time field's type, e.g. minutes, hours, days of month, etc.
Parse a string into a sequence of numbers that represent a given Date-Time field's type, e.g. minutes, hours, days of month, etc.
(get-current-dt)(get-current-dt tz)Get current date time
Get current date time
(get-dt year month day hour minute)(get-dt year month day hour minute tz)Return ZonedDateTime in given time zone/UTC or nil for invalid Date-Time
Return ZonedDateTime in given time zone/UTC or nil for invalid Date-Time
(seq-contains? coll e)Return true if a sequence contains the element
Return true if a sequence contains the element
(validate-value start end field)Return true if value for the given field is valid, throw an exception otherwise
Return true if value for the given field is valid, throw an exception otherwise
Parse a string with the values into a range of integers
Parse a string with the values into a range of integers
(value->ordinal s)Return an ordinal integer number with the proper suffix in English, e.g. 1 -> 1st, 2 -> 2nd, 3 -> 3rd, 15 -> 15th, etc.
Return an ordinal integer number with the proper suffix in English, e.g. 1 -> 1st, 2 -> 2nd, 3 -> 3rd, 15 -> 15th, etc.
Parse a string with the values into a human-readable text
Parse a string with the values into a human-readable text
Parse a frament of the value into a human readable text
Parse a frament of the value into a human readable text
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |